==> sangjog-cli-0.1.0.tgz: package/lib/sangjog-zip-extractor.js <==
const request = require('request');
const { Readable } = require('stream');
const fs = require("fs");
const unzip = require('unzip-stream');
const nodePath = require('path');

class SangjogZipExtractor {

    static extractFromBuffArr(buffArr, options, completeFn) {
        const buff = Buffer.concat(buffArr);
        const stream = Readable.from(buff).pipe(unzip.Parse());
        SangjogZipExtractor.extractFromStream(stream, options, completeFn);
    }

    static extractFromStream(stream, options, completeFn) {
        stream.on('entry', (entry, e, cb) => {
            const { path, isDirectory } = entry;
            const { inWhichDir, zipFolderName, devProjectName } = options;
            const projPath = nodePath.join(inWhichDir, path);
            const sangjogDirPath = projPath.replace(zipFolderName, devProjectName);
            if(path) {
                if(isDirectory) {
                    if(!fs.existsSync(sangjogDirPath)) {
                        fs.mkdirSync(sangjogDirPath);
                    }
                } else {
                    entry.pipe(fs.createWriteStream(sangjogDirPath));
                }
            } else {
                entry.autodrain();
            }
        });
        completeFn();
    }

    static downloadFile(filePath, options, completeFn) {
        const buffArr = [];
        request.get(filePath).on('data', (buff)=>{
            buffArr.push(buff);
        }).on('error', (err) => {
            if(err && err.host && err.host.indexOf('github.com')>-1) {
                console.log('Network issue. trying again....');
                SangjogZipExtractor.downloadFile(filePath, options, completeFn);
            } else {
                console.error(err);
            }
        }).on('complete', (response)=>{
            if(response && response.statusCode===200) {
                SangjogZipExtractor.extractFromBuffArr(buffArr, options, completeFn);
            }
        });
    }

}

module.exports = SangjogZipExtractor;

==> sangjog-cli-0.7.0.tgz: package/lib/sangjog-zip-extractor.js <==
/***
 * Sangjog CLI
 * Copyright(c) 2022 Hirak Santra
 */
 'use strict';

const request = require('request');
const { Readable } = require('stream');
const fs = require("fs");
const unzip = require('unzip-stream');
const nodePath = require('path');

class SangjogZipExtractor {

    static extractFromBuffArr(buffArr, options, completeFn) {
        const buff = Buffer.concat(buffArr);
        const stream = Readable.from(buff).pipe(unzip.Parse());
        SangjogZipExtractor.extractFromStream(stream, options, completeFn);
    }

    static extractFromStream(stream, options, completeFn) {
        stream.on('entry', (entry, e, cb) => {
            const { path, file, isDirectory } = entry;
            const { inWhichDir, zipFolderName, devProjectName } = options;
            const projPath = nodePath.join(inWhichDir, path);
            const sangjogDirPath = projPath.replace(zipFolderName, devProjectName);
            if(path) {
                if(isDirectory) {
                    if(!fs.existsSync(sangjogDirPath)) {
                        fs.mkdirSync(sangjogDirPath);
                    }
                } else {
                    entry.pipe(fs.createWriteStream(sangjogDirPath));
                }
            } else {
                entry.autodrain();
            }
        });
        setTimeout(()=>{
            completeFn();
        }, 50)
    }

    static downloadFile(filePath, options, completeFn) {
        const buffArr = [];
        request.get(filePath).on('data', (buff)=>{
            buffArr.push(buff);
        }).on('error', (err) => {
            if(err && err.host && err.host.indexOf('github.com')>-1) {
                console.log('Network issue. trying again....');
                SangjogZipExtractor.downloadFile(filePath, options, completeFn);
            } else {
                console.error(err);
            }
        }).on('complete', (response)=>{
            if(response && response.statusCode===200) {
                SangjogZipExtractor.extractFromBuffArr(buffArr, options, completeFn);
            }
        });
    }

    static modifyPackageJson(options) {
        const {projName, name, currentDir} = options;
        const packageFilePath = nodePath.join(currentDir, name, 'package.json');
        const file = require(packageFilePath);
        file.name = projName;
        file.scripts = {};
        fs.writeFile(packageFilePath, JSON.stringify(file, null, 2), function(err) {
            if (err) return console.log(err);
        });
    }

}

module.exports = SangjogZipExtractor;
